import { AxiosInstance, AxiosRequestConfig } from 'axios';
import { CookieJar } from 'tough-cookie';
import * as API from './types';
export default class TikTokAPI {
    readonly config: API.TikTokAPIConfig;
    readonly cookieJar: CookieJar;
    readonly request: AxiosInstance;
    constructor(reqParams: API.StaticRequestParams, apiConfig: API.TikTokAPIConfig, requestConfig?: AxiosRequestConfig);
    loginWithEmail: (email: string, password: string) => Promise<import("axios").AxiosResponse<API.LoginResponse>>;
    loginWithUsername: (username: string, password: string) => Promise<import("axios").AxiosResponse<API.LoginResponse>>;
    login: (params: API.LoginRequest) => Promise<import("axios").AxiosResponse<API.LoginResponse>>;
    getUser: (userId: string) => import("axios").AxiosPromise<API.UserProfileResponse | API.BaseResponseData>;
    searchUsers: (params: API.UserSearchRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.UserSearchResponse>;
    getQRCode: (userId: string, schemaType?: number) => import("axios").AxiosPromise<API.BaseResponseData | API.QRCodeResponse>;
    listPosts: (params: API.ListPostsRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.ListPostsResponse>;
    listFollowers: (params: API.ListFollowersRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.ListFollowersResponse>;
    listFollowing: (params: API.ListFollowingRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.ListFollowingResponse>;
    follow: (userId: string) => import("axios").AxiosPromise<API.BaseResponseData | API.FollowResponse>;
    unfollow: (userId: string) => import("axios").AxiosPromise<API.BaseResponseData | API.FollowResponse>;
    listReceivedFollowRequests: (params: API.ListReceivedFollowRequestsRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.ListReceivedFollowRequestsResponse>;
    approveFollowRequest: (userId: string) => import("axios").AxiosPromise<API.BaseResponseData | API.ApproveFollowResponse>;
    rejectFollowRequest: (userId: string) => import("axios").AxiosPromise<API.BaseResponseData | API.RejectFollowResponse>;
    likePost: (postId: string) => import("axios").AxiosPromise<API.BaseResponseData | API.LikePostResponse>;
    unlikePost: (postId: string) => import("axios").AxiosPromise<API.BaseResponseData | API.LikePostResponse>;
    listComments: (params: API.ListCommentsRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.ListCommentsResponse>;
    postComment: (postId: string, text: string, tags?: API.Tag[]) => import("axios").AxiosPromise<API.BaseResponseData | API.PostCommentResponse>;
    listCategories: (params?: API.ListCategoriesRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.ListCategoriesResponse>;
    searchHashtags: (params: API.SearchRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.HashtagSearchResponse>;
    listPostsInHashtag: (params: API.ListPostsInHashtagRequest) => import("axios").AxiosPromise<API.BaseResponseData | API.ListPostsInHashtagResponse>;
    listForYouFeed: (params?: API.ListFeedRequest | undefined) => import("axios").AxiosPromise<API.BaseResponseData | API.ListForYouFeedResponse>;
    listFollowingFeed: (params?: API.ListFeedRequest | undefined) => import("axios").AxiosPromise<API.BaseResponseData | API.ListFeedResponse>;
    joinLiveStream: (id: string) => import("axios").AxiosPromise<API.BaseResponseData | API.JoinLiveStreamResponse>;
    leaveLiveStream: (id: string) => import("axios").AxiosPromise<API.BaseResponseData>;
    canStartLiveStream: () => import("axios").AxiosPromise<API.BaseResponseData | API.CanStartLiveStreamResponse>;
    startLiveStream: (title: string, contactsAuthorized?: number) => Promise<import("axios").AxiosResponse<API.BaseResponseData | API.CreateLiveStreamRoomResponse>>;
    endLiveStream: (roomId: string, streamId: string) => import("axios").AxiosPromise<API.UpdateLiveStreamStatusResponse>;
    createLiveStreamRoom: (title: string, contactsAuthorized?: number) => import("axios").AxiosPromise<API.BaseResponseData | API.CreateLiveStreamRoomResponse>;
    updateLiveStreamStatus: (params: API.UpdateLiveStreamStatusRequest) => import("axios").AxiosPromise<API.UpdateLiveStreamStatusResponse>;
    transformResponse: (data: any) => any;
    private signRequest;
}
export declare const getRequestParams: (requestParams: API.RequiredUserDefinedRequestParams) => API.StaticRequestParams;
export * from './types';
